@@ -51,9 +51,9 @@ function build_graphite_options(options, raw) {
                         // so we need a good string identifier and set it using alias() (which graphite will honor)
                         // so that we recognize the returned output. simplest is just to include the target spec again
                         // though this duplicates a lot of info in the url.
-                        clean_options.push("target=alias(" + encodeURIComponent(value.target) + ",'" + value.target +"')");
+                        clean_options.push("target=alias(" + encodeURIComponent(value.target) + ",'" + encodeURIComponent(value.target) +"')");
                     } else {
-                        clean_options.push("target=alias(color(" +encodeURIComponent(value.target + ",'" + value.color) +"'),'" + value.name +"')");
+                        clean_options.push("target=alias(color(" +encodeURIComponent(value.target + ",'" + value.color) +"'),'" + encodeURIComponent(value.name) +"')");
                     }
             });
         } else if (value !== null) {
@@ -339,10 +339,16 @@ function find_definition (target_graphite, options) {
                     }
                 }
                 if('title' in options) {
-                    options['xaxes'] = [{axisLabel: options['title']}];
+                    if(!options['xaxes']) {
+                      options['xaxes'] = [{}];
+                    }
+                    $.extend(options['xaxes'][0],{axisLabel: options['title']});
                 }
                 if('vtitle' in options) {
-                    options['yaxes'] = [{position: 'left', axisLabel: options['vtitle']}];
+                    if(!options['yaxes']) {
+                      options['yaxes'] = [{}];
+                    }
+                    $.extend(options['yaxes'][0], {position: 'left', axisLabel: options['vtitle']});
                 }
                 for (i = 0; i < options['targets'].length; i++ ) {
                     options['targets'][i]['color'] = options['targets'][i]['color'];
